@@ -52,6 +52,10 @@ public interface ScenarioSimulationEditorConstants
 
     String testEditor();
 
+    String testToolsAddButton();
+
+    String testToolsAddButtonLabel();
+
     String scenarioCheatSheet();
 
     String ruleCheatSheet1();
@@ -148,12 +152,16 @@ public interface ScenarioSimulationEditorConstants
 
     String deleteColumn();
 
+    String deleteInstance();
+
     String duplicateInstance();
 
     String insertRowBelow();
 
     String scenario();
 
+    String background();
+
     String given();
 
     String insertRowAbove();
@@ -180,6 +188,8 @@ public interface ScenarioSimulationEditorConstants
 
     String dateFormatPlaceholder();
 
+    String dmnDateFormatPlaceholder();
+
     String deleteScenarioMainTitle();
 
     String deleteScenarioMainQuestion();
@@ -206,6 +216,8 @@ public interface ScenarioSimulationEditorConstants
 
     String defineValidType();
 
+    String insertExpression();
+
     String changeType();
 
     String changeTypeMainTitle();
@@ -274,6 +286,8 @@ public interface ScenarioSimulationEditorConstants
 
     String complexTypes();
 
+    String dataObjectInstances();
+
     String complexCustomInstances();
 
     String simpleCustomInstances();
@@ -312,5 +326,35 @@ public interface ScenarioSimulationEditorConstants
 
     String noRulesAvailable();
 
+    String headerTitleEmptyError();
+
     String instanceTitleAssignedError(String title);
+
+    String instanceTitleWithPeriodsError();
+
+    String propertyTitleAssignedError(String title);
+
+    String propertyTitleWithPeriodsError();
+
+    String validationErrorTitle();
+
+    String validationErrorMessage();
+
+    String validationFailedNotification();
+
+    String validationSucceed();
+
+    String backgroundTabTitle();
+
+    String export();
+
+    String backgroundErrorNotification();
+
+    String testToolsDescription();
+
+    String testToolObjectSelectionTitle();
+
+    String testToolObjectSelectionTooltip();
+
+    String testToolClearSelection();
 }
